@@ -1774,7 +1774,8 @@ CAnsiTerm::ProcessSGR(void)
             break;
 
         default:
-            assert(false);
+	    	dbglog("ERROR: bad SGR param %d (0x%02x)\n",index,index);
+            m_Attribute = kDefaultAttribute;
             break;
         }
     }
@@ -1798,6 +1799,7 @@ CAnsiTerm::ProcessSM(void)
             {
             case 0:
             default:
+	    		dbglog("ERROR: bad private SM param %d\n",m_Parameters[0]);
                 assert(false);
                 break;
             case DECCKM:
@@ -1846,8 +1848,9 @@ CAnsiTerm::ProcessSM(void)
             {
             case 20: m_bLineFeedNewLineMode = true; break;  // LNM
             default: 
-		dbglog("ProcessSM: param %d != 20\n",m_Parameters[0]);
-		assert(false);                 break;
+				dbglog("ProcessSM: param %d != 20\n",m_Parameters[0]);
+				assert(false);                 
+				break;
             }
         }
     }
