@@ -172,8 +172,13 @@ typedef struct
 /*
  * Global variables 
  */
-static char * progver   = "3.07";
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil config";
+#else
+static char * progver   = "3.08";
 static char * progname  = "iconfig";
+#endif
 static char   fdebug    = 0;
 static char   fipmilan  = 0;
 static FILE * fd_bmc    = NULL;
