@@ -241,16 +241,16 @@ static void dbgmsg(char *pattn, ...)
     fflush( fpdbg );
 }
 
-int set_cloexec(fd,fdebugcmd)
+int set_cloexec(int fd, int fdebugcmd)
 {
     int flags;
-	flags = fcntl(ipmi_fd, F_GETFD);
+	flags = fcntl(fd, F_GETFD);
 	if (flags == -1) {
 	   if (fdebugcmd) printf("fcntl(get) errno = %d\n",errno);
        return -1;
     }
 	flags |= FD_CLOEXEC;
-	if (fcntl(ipmi_fd, F_SETFD, flags) == -1)
+	if (fcntl(fd, F_SETFD, flags) == -1)
     {
 	   if (fdebugcmd) printf("fcntl(set) errno = %d\n",errno);
        return -1;
