@@ -707,7 +707,7 @@ int get_MemDesc(UCHAR array, UCHAR dimm, char *desc, int *psize)
 	}
 	closeSmBios(VirtualAddress,SMBiosLen);
 	/* fill in a default if error */
-	if ((rv != 0) && (desc != NULL)) sprintf(desc,"DIMM[%d]",dimm);
+	if ((rv != 0) && (desc != NULL)) sprintf(desc,"DIMM(%d)",dimm);
 	return rv;
 } //get_MemDesc
 
